@@ -15,8 +15,8 @@ in the internal development web server
 	try:
 		sys.path.insert(0, '.')
 		__import__('urls')
-	except ImportError:
-		sys.stderr.write("Cannot find valid urls.py. Is this a simpleweb project directory?\n")
+	except ImportError, e:
+		sys.stderr.write("Could not successfully import urls.py. Details follow:\n\t%s\n" % (e))
 	else:
 		simpleweb.run()
 	
